@@ -33,7 +33,7 @@ acm_article <- function(...) {
 
 #' @section `acs_article`: Format for creating an American Chemical Society
 #'   (ACS) Journal articles. Adapted from
-#'   <https://pubs.acs.org/page/4authors/submission/tex.html>.
+#'   `https://pubs.acs.org/page/4authors/submission/tex.html`
 #' @export
 #' @rdname article
 acs_article <- function(..., keep_tex = TRUE,
@@ -100,7 +100,7 @@ ams_article <- function(..., keep_tex = TRUE,
 }
 
 #' @section `asa_article`: This format was adapted from The American
-#'   Statistican (TAS) format, but it should be fairly consistent across
+#'   Statistician (TAS) format, but it should be fairly consistent across
 #'   American Statistical Association (ASA) journals.
 #' @export
 #' @rdname article
@@ -330,6 +330,21 @@ lipics_article <- function(..., latex_engine = "xelatex", # xelatex used for 'th
   )
 }
 
+
+#' @section `lncs_article`: Format for creating submissions to
+#'   LNCS - Lecture Notes in Computer Science - articles.
+#'   Adapted from the official Instructions for Authors at
+#'   <https://www.springer.com/gp/computer-science/lncs/conference-proceedings-guidelines>
+#'   and the  template from the archive `LaTeX2e+Proceedings+Templates+download.zip` downloaded
+#'   with version tag 2.21.
+#' @export
+#' @rdname article
+lncs_article <- function(..., keep_tex = TRUE, citation_package = c("default", "natbib")) {
+  citation_package <- match.arg(citation_package)
+  pdf_document_format("lncs", keep_tex = keep_tex, citation_package = citation_package, ...)
+}
+
+
 #' @section `jedm_article`: Format for creating Journal of Educational
 #'   Data Mining (JEDM) articles. Adapted from
 #'   <https://jedm.educationaldatamining.org/index.php/JEDM/information/authors>.
@@ -444,7 +459,7 @@ sage_article <- function(..., highlight = NULL, citation_package = "natbib") {
 
 #' @section `sim_article`: Format for creating submissions to Statistics in
 #'   Medicine. Based on the official Statistics in Medicine
-#'   [class](http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1097-0258/homepage/la_tex_class_file.htm).
+#'   at `https://onlinelibrary.wiley.com/page/journal/10970258/homepage/la_tex_class_file.htm`.
 #'
 #' Possible arguments for the YAML header are:
 #' * `title` title of the manuscript
